Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Payment Cryptography.

Actions, resources, and condition keys for AWS Payment Cryptography - Service Authorization Reference

# Actions, resources, and condition keys for AWS Payment Cryptography

AWS Payment Cryptography (service prefix: `payment-cryptography` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Payment Cryptography
- Resource types defined by AWS Payment Cryptography
- Condition keys for AWS Payment Cryptography

## Actions defined by AWS Payment Cryptography

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAlias | Grants permission to create a user-friendly name for a Key | Write | alias* |  |
key* |  |
CreateKey | Grants permission to create a unique customer managed key in the caller's AWS account and region | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | payment-cryptography:TagResource
DecryptData | Grants permission to decrypt ciphertext data to plaintext using symmetric, asymmetric or DUKPT data encryption key | Write |  |  |
DeleteAlias | Grants permission to delete the specified alias | Write | alias* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteKey | Grants permission to schedule the deletion of a Key | Write | key* |  |
EncryptData | Grants permission to encrypt plaintext data to ciphertext using symmetric, asymmetric or DUKPT data encryption key | Write |  |  |
ExportKey | Grants permission to export a key from the service | Write | key* |  |
GenerateCardValidationData | Grants permission to generate card-related data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) or Card Security Codes (CSC) that check the validity of a magnetic stripe card | Write |  |  |
GenerateMac | Grants permission to generate a MAC (Message Authentication Code) cryptogram | Write |  |  |
GeneratePinData | Grants permission to generate pin-related data such as PIN, PIN Verification Value (PVV), PIN Block and PIN Offset during new card issuance or card re-issuance | Write |  |  |
GetAlias | Grants permission to return the keyArn associated with an aliasName | Read | alias* |  |
key* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GetKey | Grants permission to return the detailed information about the specified key | Read | key* |  |
GetParametersForExport | Grants permission to get the export token and the signing key certificate to initiate a TR-34 key export | Read |  |  |
GetParametersForImport | Grants permission to get the import token and the wrapping key certificate to initiate a TR-34 key import | Read |  |  |
GetPublicKeyCertificate | Grants permission to return the public key from a key of class PUBLIC_KEY | Read | key* |  |
ImportKey | Grants permission to imports keys and public key certificates | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | payment-cryptography:TagResource
ListAliases | Grants permission to return a list of aliases created for all keys in the caller's AWS account and Region | List | alias* |  |
key* |  |
ListKeys | Grants permission to return a list of keys created in the caller's AWS account and Region | List | key* |  |
ListTagsForResource | Grants permission to return a list of tags created in the caller's AWS account and Region | Read | key |  |
ReEncryptData | Grants permission to re-encrypt ciphertext using DUKPT, Symmetric and Asymmetric Data Encryption Keys | Write |  |  |
RestoreKey | Grants permission to cancel a scheduled key deletion if at any point during the waiting period a Key needs to be revived | Write | key* |  |
StartKeyUsage | Grants permission to enable a disabled Key | Write | key* |  |
StopKeyUsage | Grants permission to disable an enabled Key | Write | key* |  |
TagResource | Grants permission to add or overwrites one or more tags for the specified resource | Tagging | key* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TranslatePinData | Grants permission to translate encrypted PIN block from and to ISO 9564 formats 0,1,3,4 | Write |  |  |
UntagResource | Grants permission to remove the specified tag or tags from the specified resource | Tagging | key* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateAlias | Grants permission to change the key to which an alias is assigned, or unassign it from its current key | Write | alias* |  |
key* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
VerifyAuthRequestCryptogram | Grants permission to verify Authorization Request Cryptogram (ARQC) for a EMV chip payment card authorization | Write |  |  |
VerifyCardValidationData | Grants permission to verify card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) and Card Security Codes (CSC) | Write |  |  |
VerifyMac | Grants permission to verify MAC (Message Authentication Code) of input data against a provided MAC | Write |  |  |
VerifyPinData | Grants permission to verify pin-related data such as PIN and PIN Offset using algorithms including VISA PVV and IBM3624 | Write |  |  |

## Resource types defined by AWS Payment Cryptography

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
key | `arn:$ { Partition}:payment-cryptography:$ { Region}:$ { Account}:key/$ { KeyId}` | aws:ResourceTag/${TagKey} payment-cryptography:ResourceAliases
alias | `arn:$ { Partition}:payment-cryptography:$ { Region}:$ { Account}:alias/$ { Alias}` | payment-cryptography:ResourceAliases

## Condition keys for AWS Payment Cryptography

AWS Payment Cryptography defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by both the key and value of the tag in the request for the specified operation | String
aws:ResourceTag/${TagKey} | Filters access by tags assigned to a key for the specified operation | String
aws:TagKeys | Filters access by the tag keys in the request for the specified operation | ArrayOfString
payment-cryptography:CertificateAuthorityPublicKeyIdentifier | Filters access by the CertificateAuthorityPublicKeyIdentifier specified in the request or the ImportKey, and ExportKey operations | String
payment-cryptography:ImportKeyMaterial | Filters access by the type of key material being imported [RootCertificatePublicKey, TrustedCertificatePublicKey, Tr34KeyBlock, Tr31KeyBlock] for the ImportKey operation | String
payment-cryptography:KeyAlgorithm | Filters access by KeyAlgorithm specified in the request for the CreateKey operation | String
payment-cryptography:KeyClass | Filters access by KeyClass specified in the request for the CreateKey operation | String
payment-cryptography:KeyUsage | Filters access by KeyClass specified in the request or associated with a key for the CreateKey operation | String
payment-cryptography:RequestAlias | Filters access by aliases in the request for the specified operation | String
payment-cryptography:ResourceAliases | Filters access by aliases associated with a key for the specified operation | ArrayOfString
payment-cryptography:WrappingKeyIdentifier | Filters access by the WrappingKeyIdentifier specified in the request for the ImportKey, and ExportKey operations | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.